@@ -22,12 +22,14 @@
 #![allow(
 	clippy::module_name_repetitions,
 	clippy::must_use_candidate,
-	clippy::missing_errors_doc
+	clippy::missing_errors_doc,
+	clippy::empty_docs
 )]
 //TODO:
 #![allow(
 	clippy::significant_drop_tightening,
-	clippy::missing_panics_doc
+	clippy::missing_panics_doc,
+	clippy::multiple_crate_versions
 )]
 
 pub mod asyncjob;
