@@ -1,3 +1,5 @@
+use chrono::TimeZone;
+
 fn get_git_hash() -> String {
 	use std::process::Command;
 
@@ -18,7 +20,13 @@ fn get_git_hash() -> String {
 }
 
 fn main() {
-	let build_date = chrono::Local::now().date_naive();
+	let now = match std::env::var("SOURCE_DATE_EPOCH") {
+		Ok(val) => chrono::Local
+			.timestamp_opt(val.parse::<i64>().unwrap(), 0)
+			.unwrap(),
+		Err(_) => chrono::Local::now(),
+	};
+	let build_date = now.date_naive();
 
 	let build_name = if std::env::var("GITUI_RELEASE").is_ok() {
 		format!(
