@@ -4,12 +4,12 @@ use super::{
 	CommandBlocking, DrawableComponent,
 };
 use crate::{
+	app::Environment,
 	components::{CommandInfo, Component, EventState},
 	keys::{key_match, SharedKeyConfig},
 	options::SharedOptions,
 	queue::{Action, InternalEvent, NeedsUpdate, Queue, ResetItem},
 	strings, try_or_popup,
-	ui::style::SharedTheme,
 };
 use anyhow::Result;
 use asyncgit::{
@@ -17,8 +17,8 @@ use asyncgit::{
 	StatusItem, StatusItemType,
 };
 use crossterm::event::Event;
+use ratatui::{layout::Rect, Frame};
 use std::path::Path;
-use tui::{backend::Backend, layout::Rect, Frame};
 
 ///
 pub struct ChangesComponent {
@@ -32,31 +32,19 @@ pub struct ChangesComponent {
 
 impl ChangesComponent {
 	///
-	//TODO: fix
-	#[allow(clippy::too_many_arguments)]
 	pub fn new(
-		repo: RepoPathRef,
+		env: &Environment,
 		title: &str,
 		focus: bool,
 		is_working_dir: bool,
-		queue: Queue,
-		theme: SharedTheme,
-		key_config: SharedKeyConfig,
-		options: SharedOptions,
 	) -> Self {
 		Self {
-			files: StatusTreeComponent::new(
-				title,
-				focus,
-				Some(queue.clone()),
-				theme,
-				key_config.clone(),
-			),
+			files: StatusTreeComponent::new(env, title, focus),
 			is_working_dir,
-			queue,
-			key_config,
-			options,
-			repo,
+			queue: env.queue.clone(),
+			key_config: env.key_config.clone(),
+			options: env.options.clone(),
+			repo: env.repo.clone(),
 		}
 	}
 
@@ -84,8 +72,8 @@ impl ChangesComponent {
 	}
 
 	///
-	pub fn is_file_seleted(&self) -> bool {
-		self.files.is_file_seleted()
+	pub fn is_file_selected(&self) -> bool {
+		self.files.is_file_selected()
 	}
 
 	fn index_add_remove(&mut self) -> Result<bool> {
@@ -109,7 +97,7 @@ impl ChangesComponent {
 					let config =
 						self.options.borrow().status_show_untracked();
 
-					//TODO: check if we can handle the one file case with it aswell
+					//TODO: check if we can handle the one file case with it as well
 					sync::stage_add_all(
 						&self.repo.borrow(),
 						tree_item.info.full_path.as_str(),
@@ -160,12 +148,9 @@ impl ChangesComponent {
 
 	fn dispatch_reset_workdir(&mut self) -> bool {
 		if let Some(tree_item) = self.selection() {
-			let is_folder =
-				matches!(tree_item.kind, FileTreeItemKind::Path(_));
 			self.queue.push(InternalEvent::ConfirmAction(
 				Action::Reset(ResetItem {
 					path: tree_item.info.full_path,
-					is_folder,
 				}),
 			));
 
@@ -199,11 +184,7 @@ impl ChangesComponent {
 }
 
 impl DrawableComponent for ChangesComponent {
-	fn draw<B: Backend>(
-		&self,
-		f: &mut Frame<B>,
-		r: Rect,
-	) -> Result<()> {
+	fn draw(&self, f: &mut Frame, r: Rect) -> Result<()> {
 		self.files.draw(f, r)?;
 
 		Ok(())
