@@ -38,11 +38,9 @@ pub static POPUP_SUCCESS_COPY: &str = "Copied Text";
 pub static POPUP_COMMIT_SHA_INVALID: &str = "Invalid commit sha";
 
 pub mod symbol {
-	pub const WHITESPACE: &str = "\u{00B7}"; //·
 	pub const CHECKMARK: &str = "\u{2713}"; //✓
 	pub const SPACE: &str = "\u{02FD}"; //˽
 	pub const EMPTY_SPACE: &str = " ";
-	pub const LINE_BREAK: &str = "¶";
 	pub const FOLDER_ICON_COLLAPSED: &str = "\u{25b8}"; //▸
 	pub const FOLDER_ICON_EXPANDED: &str = "\u{25be}"; //▾
 	pub const EMPTY_STR: &str = "";
@@ -132,9 +130,9 @@ pub const fn branch_name_invalid() -> &'static str {
 	"[invalid name]"
 }
 pub fn commit_editor_msg(_key_config: &SharedKeyConfig) -> String {
-	r##"
+	r"
 # Edit your commit message
-# Lines starting with '#' will be ignored"##
+# Lines starting with '#' will be ignored"
 		.to_string()
 }
 pub fn stash_popup_title(_key_config: &SharedKeyConfig) -> String {
@@ -146,6 +144,9 @@ pub fn stash_popup_msg(_key_config: &SharedKeyConfig) -> String {
 pub fn confirm_title_reset() -> String {
 	"Reset".to_string()
 }
+pub fn confirm_title_undo_commit() -> String {
+	"Undo commit".to_string()
+}
 pub fn confirm_title_stashdrop(
 	_key_config: &SharedKeyConfig,
 	multiple: bool,
@@ -204,6 +205,9 @@ pub fn confirm_msg_reset_lines(lines: usize) -> String {
 		"are you sure you want to discard {lines} selected lines?"
 	)
 }
+pub fn confirm_msg_undo_commit() -> String {
+	"confirm undo last commit?".to_string()
+}
 pub fn confirm_msg_stashdrop(
 	_key_config: &SharedKeyConfig,
 	ids: &[CommitId],
@@ -960,17 +964,30 @@ pub mod commands {
 			CMD_GROUP_COMMIT_POPUP,
 		)
 	}
-	pub fn commit_enter(key_config: &SharedKeyConfig) -> CommandText {
+	pub fn commit_submit(
+		key_config: &SharedKeyConfig,
+	) -> CommandText {
 		CommandText::new(
 			format!(
-				"Commit [{}]",
-				key_config.get_hint(key_config.keys.enter),
+				"Do Commit [{}]",
+				key_config.get_hint(key_config.keys.commit),
 			),
 			"commit (available when commit message is non-empty)",
 			CMD_GROUP_COMMIT_POPUP,
 		)
 		.hide_help()
 	}
+	pub fn newline(key_config: &SharedKeyConfig) -> CommandText {
+		CommandText::new(
+			format!(
+				"New line [{}]",
+				key_config.get_hint(key_config.keys.newline),
+			),
+			"create line break",
+			CMD_GROUP_COMMIT_POPUP,
+		)
+		.hide_help()
+	}
 	pub fn toggle_verify(
 		key_config: &SharedKeyConfig,
 		current_verify: bool,
@@ -1002,7 +1019,7 @@ pub mod commands {
 	) -> CommandText {
 		CommandText::new(
 			format!(
-				"Sing-off [{}]",
+				"Sign-off [{}]",
 				key_config.get_hint(key_config.keys.toggle_signoff),
 			),
 			"sign-off commit (-s option)",
@@ -1339,7 +1356,7 @@ pub mod commands {
 		CommandText::new(
 			format!(
 				"Reset [{}]",
-				key_config.get_hint(key_config.keys.log_reset_comit),
+				key_config.get_hint(key_config.keys.log_reset_commit),
 			),
 			"reset to commit",
 			CMD_GROUP_LOG,
@@ -1351,7 +1368,8 @@ pub mod commands {
 		CommandText::new(
 			format!(
 				"Reword [{}]",
-				key_config.get_hint(key_config.keys.log_reword_comit),
+				key_config
+					.get_hint(key_config.keys.log_reword_commit),
 			),
 			"reword commit message",
 			CMD_GROUP_LOG,
@@ -1385,17 +1403,29 @@ pub mod commands {
 	pub fn reset_commit(key_config: &SharedKeyConfig) -> CommandText {
 		CommandText::new(
 			format!(
-				"Confirm  [{}]",
+				"Confirm [{}]",
 				key_config.get_hint(key_config.keys.enter),
 			),
 			"confirm reset",
 			CMD_GROUP_LOG,
 		)
 	}
+
+	pub fn reset_branch(key_config: &SharedKeyConfig) -> CommandText {
+		CommandText::new(
+			format!(
+				"Reset [{}]",
+				key_config.get_hint(key_config.keys.reset_branch),
+			),
+			"confirm reset",
+			CMD_GROUP_BRANCHES,
+		)
+	}
+
 	pub fn reset_type(key_config: &SharedKeyConfig) -> CommandText {
 		CommandText::new(
 			format!(
-				"Change Type  [{}{}]",
+				"Change Type [{}{}]",
 				key_config.get_hint(key_config.keys.move_up),
 				key_config.get_hint(key_config.keys.move_down)
 			),
@@ -1405,11 +1435,16 @@ pub mod commands {
 	}
 	pub fn tag_commit_confirm_msg(
 		key_config: &SharedKeyConfig,
+		is_annotation_mode: bool,
 	) -> CommandText {
 		CommandText::new(
 			format!(
 				"Tag [{}]",
-				key_config.get_hint(key_config.keys.enter),
+				key_config.get_hint(if is_annotation_mode {
+					key_config.keys.commit
+				} else {
+					key_config.keys.enter
+				}),
 			),
 			"tag commit",
 			CMD_GROUP_LOG,
