@@ -8,7 +8,7 @@ use struct_patch::Patch;
 
 pub type SharedTheme = Rc<Theme>;
 
-#[derive(Serialize, Deserialize, Debug, Copy, Clone, Patch)]
+#[derive(Serialize, Deserialize, Debug, Clone, Patch)]
 #[patch_derive(Serialize, Deserialize)]
 pub struct Theme {
 	selected_tab: Color,
@@ -32,6 +32,8 @@ pub struct Theme {
 	push_gauge_fg: Color,
 	tag_fg: Color,
 	branch_fg: Color,
+	line_break: String,
+	block_title_focused: Color,
 }
 
 impl Theme {
@@ -49,7 +51,9 @@ impl Theme {
 
 	pub fn title(&self, focused: bool) -> Style {
 		if focused {
-			Style::default().add_modifier(Modifier::BOLD)
+			Style::default()
+				.fg(self.block_title_focused)
+				.add_modifier(Modifier::BOLD)
 		} else {
 			Style::default().fg(self.disabled_fg)
 		}
@@ -139,7 +143,11 @@ impl Theme {
 		self.apply_select(style, selected)
 	}
 
-	fn apply_select(&self, style: Style, selected: bool) -> Style {
+	const fn apply_select(
+		&self,
+		style: Style,
+		selected: bool,
+	) -> Style {
 		if selected {
 			style.bg(self.selection_bg).fg(self.selection_fg)
 		} else {
@@ -192,6 +200,10 @@ impl Theme {
 		Style::default().fg(self.danger_fg)
 	}
 
+	pub fn line_break(&self) -> String {
+		self.line_break.clone()
+	}
+
 	pub fn commandbar(&self, enabled: bool, line: usize) -> Style {
 		if enabled {
 			Style::default().fg(self.command_fg)
@@ -278,7 +290,7 @@ impl Theme {
 	// This is supposed to be called when theme.ron doesn't already exists.
 	fn save_patch(&self, theme_path: &PathBuf) -> Result<()> {
 		let mut file = File::create(theme_path)?;
-		let patch = self.into_patch_by_diff(Self::default());
+		let patch = self.clone().into_patch_by_diff(Self::default());
 		let data = to_string_pretty(&patch, PrettyConfig::default())?;
 
 		file.write_all(data.as_bytes())?;
@@ -289,7 +301,10 @@ impl Theme {
 	pub fn init(theme_path: &PathBuf) -> Self {
 		let mut theme = Self::default();
 
-		if let Ok(patch) = Self::load_patch(theme_path) {
+		if let Ok(patch) = Self::load_patch(theme_path).map_err(|e| {
+			log::error!("theme error [{:?}]: {e}", theme_path);
+			e
+		}) {
 			theme.apply(patch);
 		} else if let Ok(old_theme) = Self::load_old_theme(theme_path)
 		{
@@ -336,6 +351,8 @@ impl Default for Theme {
 			push_gauge_fg: Color::Reset,
 			tag_fg: Color::LightMagenta,
 			branch_fg: Color::LightYellow,
+			line_break: "¶".to_string(),
+			block_title_focused: Color::Reset,
 		}
 	}
 }
@@ -344,20 +361,24 @@ impl Default for Theme {
 mod tests {
 	use super::*;
 	use pretty_assertions::assert_eq;
-	use std::io::Write;
 	use tempfile::NamedTempFile;
 
 	#[test]
 	fn test_smoke() {
+		let _ = env_logger::builder()
+			.is_test(true)
+			.filter_level(log::LevelFilter::Trace)
+			.try_init();
+
 		let mut file = NamedTempFile::new().unwrap();
 
 		writeln!(
 			file,
-			r"
+			r#"
 (
-	selection_bg: Some(White),
+	selection_bg: Some("White"),
 )
-"
+"#
 		)
 		.unwrap();
 
